"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_path_1 = __importDefault(require("node:path"));
const node_util_1 = require("node:util");
const fs_extra_1 = __importDefault(require("fs-extra"));
const validator = __importStar(require("../../registry/domain/validators"));
const require_template_1 = __importDefault(require("./handle-dependencies/require-template"));
function checkSizes(folder) {
    const jsFiles = fs_extra_1.default.readdirSync(folder).filter((x) => x.endsWith('.js'));
    const sizes = {
        client: 0
    };
    for (const file of jsFiles) {
        if (file === 'server.js') {
            sizes.server = fs_extra_1.default.statSync(node_path_1.default.join(folder, file)).size;
        }
        else {
            sizes.client += fs_extra_1.default.statSync(node_path_1.default.join(folder, file)).size;
        }
    }
    return sizes;
}
function addSizes(folder, component, sizes) {
    component.oc.files.template.size = sizes.client;
    if (sizes.server) {
        component.oc.files.dataProvider.size = sizes.server;
    }
    fs_extra_1.default.writeJsonSync(node_path_1.default.join(folder, 'package.json'), component, { spaces: 2 });
}
const packageComponents = () => async (options) => {
    const production = options.production;
    const componentPath = options.componentPath;
    const minify = options.minify === true;
    const verbose = options.verbose === true;
    const publishPath = node_path_1.default.join(componentPath, '_package');
    const componentPackagePath = node_path_1.default.join(componentPath, 'package.json');
    const ocPackagePath = node_path_1.default.join(__dirname, '../../../package.json');
    if (!fs_extra_1.default.existsSync(componentPackagePath)) {
        throw new Error('component does not contain package.json');
    }
    if (!fs_extra_1.default.existsSync(ocPackagePath)) {
        throw new Error('error resolving oc internal dependencies');
    }
    await fs_extra_1.default.emptyDir(publishPath);
    const componentPackage = await fs_extra_1.default.readJson(componentPackagePath);
    const ocPackage = await fs_extra_1.default.readJson(ocPackagePath);
    if (!validator.validateComponentName(componentPackage.name)) {
        throw new Error('name not valid');
    }
    const type = componentPackage.oc.files.template.type;
    const compileOptions = {
        publishPath,
        componentPath,
        componentPackage,
        ocPackage,
        minify,
        verbose,
        production
    };
    const ocTemplate = (0, require_template_1.default)(type, {
        compiler: true,
        componentPath
    });
    const compile = (0, node_util_1.promisify)(ocTemplate.compile);
    const component = await compile(compileOptions);
    addSizes(publishPath, component, checkSizes(publishPath));
    return component;
};
exports.default = packageComponents;
